### What can it be used for?

<!--- describe how this could be used / the use case for this icon -->

### Example image (optional)

<!--- insert the example image here if necessary -->

### Icon request checklist

- [ ] This is a single icon or matched pair (Ex: `lock` / `unlock`)
- [ ] The title starts with "Icon request: " and is followed by the requested icon name (Ex: `Icon request: magical-unicorn`)
- [ ] I have [searched for existing issues](https://github.com/FortAwesome/Font-Awesome/issues) and to the best of my knowledge this is not a duplicate
- [ ] I have included at least one example image if it could be helpful (optional)
- [ ] The request is for a concrete object (it's harder to make an icon to represent happiness, it's easier to make a smiley face. ☺)
